==> knox-1.2.0-src.zip: knox-1.2.0/gateway-shell/src/main/java/org/apache/knox/gateway/shell/AbstractJavaConsoleCredentialCollector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.shell;

import java.io.Console;

public abstract class AbstractJavaConsoleCredentialCollector extends AbstractCredentialCollector {

  public AbstractJavaConsoleCredentialCollector() {
    super();
  }

  protected String collectClearCredential(String prompt) {
    Console c = System.console();
    if (c == null) {
      System.err.println("No console.");
      System.exit(1);
    }
  
    String username = c.readLine(prompt);
    value = username;
  
    return value;
  }

  protected String collectHiddenCredential(String prompt) {
    char[] response = null;
    Console c = System.console();
    if (c == null) {
      System.err.println("No console.");
      System.exit(1);
    }
  
    response = c.readPassword(prompt);
    value = new String(response);
  
    return value;
  }

  @Override
  public boolean validate() {
    boolean rc = true;
    if (value == null || value.isEmpty()) {
      rc = false;
    }
    return rc;
  }
}

==> knox-1.4.0-src.zip: knox-1.4.0/gateway-shell/src/main/java/org/apache/knox/gateway/shell/AbstractJavaConsoleCredentialCollector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.shell;

import java.io.Console;

public abstract class AbstractJavaConsoleCredentialCollector extends AbstractCredentialCollector {

  public AbstractJavaConsoleCredentialCollector() {
    super();
  }

  protected String collectClearCredential(String prompt) {
    Console c = System.console();
    if (c == null) {
      System.err.println("No console.");
      System.exit(1);
    }

    value = c.readLine(prompt);

    return value;
  }

  protected String collectHiddenCredential(String prompt) {
    char[] response;
    Console c = System.console();
    if (c == null) {
      System.err.println("No console.");
      System.exit(1);
    }

    response = c.readPassword(prompt);
    value = new String(response);

    return value;
  }

  @Override
  public boolean validate() {
    boolean rc = true;
    if (value == null || value.isEmpty()) {
      rc = false;
    }
    return rc;
  }
}
